<template>
    <div >
        <!-- Add notes -->
        <FormAdd ref="noteAdd"></FormAdd>
        <!-- view notes -->
        <NoteShow ref="noteShow"></NoteShow>
        <!-- edit contact -->
        <NoteEdit ref="noteEdit"></NoteEdit>

        <v-card>
            <v-card-title>
                <div>
                    <div class="headline">
                        {{ trans('messages.documents_notes') }}
                    </div>
                </div>
                <v-spacer></v-spacer>
                <v-btn class="primary lighten-1" dark @click="create">
                    {{ trans('messages.add') }}
                    <v-icon right dark>add</v-icon>
                </v-btn>
            </v-card-title>
            <v-divider></v-divider>
            <!-- v-datatable -->
            <v-data-table
                :headers="headers"
                :options.sync="pagination"
                :server-items-length="total_items"
                :loading="loading"
                :items="items"
                class="elevation-3"
            >
                <template v-slot:item="{ item }">
                    <tr>
                        <td class="text-center">
                            <v-menu>
                                <template v-slot:activator="{ on }">
                                    <v-btn icon v-on="on">
                                        <v-icon>more_vert</v-icon>
                                    </v-btn>
                                </template>
                                <v-list>
                                    <v-list-item @click="view(item.id)">
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> visibility </v-icon>
                                            {{ trans('messages.view') }}
                                        </v-list-item-title>
                                    </v-list-item>

                                    <v-list-item @click="edit(item.id)">
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> edit </v-icon>
                                            {{ trans('messages.edit') }}
                                        </v-list-item-title>
                                    </v-list-item>

                                    <v-list-item @click="deleteNote(item)">
                                        <v-list-item-title>
                                            <v-icon small class="mr-2"> delete_forever </v-icon>
                                            {{ trans('messages.delete') }}
                                        </v-list-item-title>
                                    </v-list-item>
                                </v-list>
                            </v-menu>
                        </td>
                        <td class="text-center">{{ item.heading }}</td>
                        <td class="text-center">{{ item.user.name }}</td>
                        <td class="text-center">
                            {{ item.created_at | formatDate }}
                        </td>
                        <td class="text-center">
                            {{ item.updated_at | formatDate }}
                        </td>
                    </tr>
                </template>
            </v-data-table>
        </v-card>
    </div>
</template>
<script>
import FormAdd from './Add';
import NoteShow from './View';
import NoteEdit from './Edit';
export default {
    components: {
        FormAdd,
        NoteShow,
        NoteEdit,
    },
    data() {
        const self = this;
        return {
            projectId: null,
            total_items: 0,
            loading: true,
            pagination: {},
            items: [],
            headers: [
                {
                    text: self.trans('messages.action'),
                    value: false,
                    align: 'center',
                    sortable: false,
                },
                {
                    text: self.trans('messages.heading'),
                    value: 'heading',
                    align: 'center',
                    sortable: true,
                },
                {
                    text: self.trans('messages.added_by'),
                    value: 'user',
                    align: 'center',
                    sortable: false,
                },
                {
                    text: self.trans('messages.created_at'),
                    value: 'created_at',
                    align: 'center',
                    sortable: true,
                },
                {
                    text: self.trans('messages.updated_at'),
                    value: 'updated_at',
                    align: 'center',
                    sortable: true,
                },
            ],
        };
    },
    watch: {
        pagination: {
            handler() {
                const self = this;
                self.getProjectNotes();
            },
        },
    },
    created() {
        const self = this;
        self.projectId = self.$route.params.id;
        self.$eventBus.$on('updateProjectNotesTable', data => {
            self.getProjectNotes();
        });
    },
    beforeDestroy() {
        const self = this;
        self.$eventBus.$off('updateProjectNotesTable');
    },
    methods: {
        getProjectNotes() {
            const self = this;

            self.loading = true;

            const { sortBy, sortDesc, page, itemsPerPage } = self.pagination;

            axios
                .get('/project-notes', {
                    params: {
                        sort_by: sortBy,
                        descending: sortDesc,
                        page: page,
                        rowsPerPage: itemsPerPage,
                        project_id: self.projectId,
                    },
                })
                .then(function(response) {
                    self.total_items = response.data.total;
                    self.items = response.data.data;
                    self.loading = false;
                })
                .catch(function(error) {
                    console.log(error);
                });
        },
        create() {
            var data = { projectId: this.projectId };
            this.$refs.noteAdd.add(data);
        },
        view(id) {
            var data = { id: id, projectId: this.projectId };
            this.$refs.noteShow.view(data);
        },
        edit(id) {
            var data = { id: id, projectId: this.projectId };
            this.$refs.noteEdit.edit(data);
        },
        deleteNote(item) {
            const self = this;
            self.$store.commit('showDialog', {
                type: 'confirm',
                icon: 'warning',
                title: self.trans('messages.are_you_sure'),
                message: self.trans('messages.you_cant_restore_it'),
                okCb: () => {
                    axios
                        .delete('/project-notes/' + item.id, {
                            params: { project_id: self.projectId },
                        })
                        .then(function(response) {
                            self.$store.commit('showSnackbar', {
                                message: response.data.msg,
                                color: response.data.success,
                            });

                            if (response.data.success === true) {
                                self.getProjectNotes();
                            }
                        })
                        .catch(function(error) {
                            console.log(error);
                        });
                },
                cancelCb: () => {
                    console.log('CANCEL');
                },
            });
        },
    },
};
</script>
